from setuptools import setup

setup(name='kk592',
      version='0.1',
      description='good mrng',
      url='http://github.com/storborg/funniest',
      author='Kamal Kumar',
      author_email='kamalsir@ymail.com',
      license='MIT',
      packages=['funniest'],
      zip_safe=False)